==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Web_Links/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_YOURNAME","sminiz");
define("_CATEGORY","Kategori");
define("_CATEGORIES","Kategori");
define("_LVOTES","oy");
define("_TOTALVOTES","Toplam Oy:");
define("_LINKTITLE","Balant Bal");
define("_HITS","Hit");
define("_THEREARE","Veritabannda");
define("_NOMATCHES","Uygun sonu bulunamad");
define("_SCOMMENTS","Yorum");
define("_DESCRIPTION","Tanm");
define("_ONLYREGUSERSMODIFY","Sadece kaytl kullanclar dosya deiiklik bavurusu yapabilir. Ltfen <a href=\"modules.php?name=Your_Account\">kayt olun veya giri yapn</a>.");
define("_DATE","Tarih");
define("_TO","Kime");
define("_ADDLINK","Balant Ekle");
define("_NEW","Yeni");
define("_POPULAR","Popler");
define("_TOPRATED","En yi");
define("_RANDOM","Rastgele");
define("_LINKSMAIN","Balantlar Anasayfa");
define("_LINKCOMMENTS","Balant Yorumlar");
define("_ADDITIONALDET","Ek Detaylar");
define("_EDITORREVIEW","Editr zlenimi");
define("_REPORTBROKEN","Krk Balant Bildir");
define("_LINKSMAINCAT","Balant Ana Kategorileri");
define("_AND","ve");
define("_INDB","bulunuyor");
define("_ADDALINK","Yeni Balant Ekle");
define("_INSTRUCTIONS","Aklamalar");
define("_SUBMITONCE","Bir balanty sadece bir kez gnderin.");
define("_POSTPENDING","Gnderilen tm balantlar onaylanmaldr.");
define("_USERANDIP","Kullanc ve IP adresi kaydedilir. Bu yzden sistemi ktye kullanmayn.");
define("_PAGETITLE","Sayfa Bal");
define("_PAGEURL","Sayfa Adresi");
define("_YOUREMAIL","Email'iniz");
define("_LDESCRIPTION","Tanm: (En fazla 255 karakter)");
define("_ADDURL","Adres Ekle");
define("_LINKSNOTUSER1","Kaytl deilsiniz veya giri yapmamsnz.");
define("_LINKSNOTUSER2","Kaytl olsaydnz bu siteye balant gnderebilecektiniz.");
define("_LINKSNOTUSER3","Kaytl kullanc olmak ksa ve basit bir ilemdir.");
define("_LINKSNOTUSER4","Neden baz zelliklere eriim iin kayt gerekli?");
define("_LINKSNOTUSER5","nk size en kaliteli ierii sunabilmek iin,");
define("_LINKSNOTUSER6","her e tek tek editrlerimiz tarafndan incelenip onaylanyor.");
define("_LINKSNOTUSER7","Size sadece deerli bilgielr sunmak istiyoruz.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Hesap Kayd</a>");
define("_LINKALREADYEXT","HATA: Bu adres zaten veritabanmzda kaytl!");
define("_LINKNOTITLE","HATA: Adres iin BALIK girmelisiniz!");
define("_LINKNOURL","HATA: Adres iin bir URL girmelisiniz!");
define("_LINKNODESC","HATA: Adres iin bir TANIM girmelisiniz!");
define("_LINKRECEIVED","Balant neriniz alnd. Teekkrler!");
define("_EMAILWHENADD","Kabul edildiinde bir email alacaksnz.");
define("_CHECKFORIT","Bir email adresi yazmadnz. Yine de balantnz kontrol edilecek.");
define("_NEWLINKS","Yeni Balantlar");
define("_TOTALNEWLINKS","Yeni Balantlar");
define("_LASTWEEK","Geen Hafta");
define("_LAST30DAYS","Son 30 Gn");
define("_1WEEK","1 Hafta");
define("_2WEEKS","2 Hafta");
define("_30DAYS","30 Gn");
define("_SHOW","Gster");
define("_TOTALFORLAST","Yeni linkler: Son");
define("_DAYS","gn");
define("_ADDEDON","Eklenme");
define("_RATING","Puan");
define("_RATESITE","Siteye Puan Ver");
define("_DETAILS","Detaylar");
define("_BESTRATED","En yi Balantlar - Top");
define("_OF","");
define("_TRATEDLINKS","toplam balant");
define("_TVOTESREQ","minimum oy gerekir");
define("_SHOWTOP","En yi");
define("_MOSTPOPULAR","En Popler - Top");
define("_OFALL","of all");
define("_SORTLINKSBY","Balantlar Srala");
define("_SITESSORTED","u Anki Sralama");
define("_POPULARITY","Poplerlik");
define("_SELECTPAGE","Sayfa Sein");
define("_MAIN","Anasayfa");
define("_NEWTODAY","Bugn");
define("_NEWLAST3DAYS","Son 3 Gn");
define("_NEWTHISWEEK","Bu Hafta");
define("_CATNEWTODAY","Bu Kategoriye Bugn Eklenen Balantlar");
define("_CATLAST3DAYS","Bu Kategoriye Son 3 Gn inde Eklenenler");
define("_CATTHISWEEK","Bu Kategoriye Bu Hafta Eklenen Balantlar");
define("_POPULARITY1","Poplerlik (En Azdan En Yksee)");
define("_POPULARITY2","Poplerlik (En Yksekten En Aza)");
define("_TITLEAZ","Balk (A - Z)");
define("_TITLEZA","Balk (Z - A)");
define("_DATE1","Tarih (Eskiler Baa)");
define("_DATE2","Tarih (Yeniler Baa)");
define("_RATING1","Puan (Dkten Yksee)");
define("_RATING2","Paun (Yksekten De)");
define("_SEARCHRESULTS4","Arama Sonular:");
define("_USUBCATEGORIES","Alt-Kategori");
define("_LINKS","Balant");
define("_TRY2SEARCH","");
define("_INOTHERSENGINES","iin dier arama motorlarn deneyin");
define("_EDITORIAL","Editrel");
define("_LINKPROFILE","Balant Profili");
define("_EDITORIALBY","Editrel:");
define("_NOEDITORIAL","Bu site iin u an editrel yok.");
define("_VISITTHISSITE","Siteyi Ziyaret Et");
define("_RATETHISSITE","Bu Kaynaa Puan Ver");
define("_ISTHISYOURSITE","Bu sizin kaynanz m?");
define("_ALLOWTORATE","Dier kullanclarn sitenizden oy vermesini salayn!");
define("_LINKRATINGDET","Balant Puan Detaylar");
define("_OVERALLRATING","Puan");
define("_TOTALOF","Toplam");
define("_USER","Kullanc");
define("_USERAVGRATING","Ortalama Puan");
define("_NUMRATINGS","Puan Says");
define("_EDITTHISLINK","Balant Dzenle");
define("_REGISTEREDUSERS","Kaytl Kullanc");
define("_NUMBEROFRATINGS","Puan Says");
define("_NOREGUSERSVOTES","Kaytl Kullanc Oyu Yok");
define("_BREAKDOWNBYVAL","Deer Bakmndan Oylar");
define("_LTOTALVOTES","toplam oy");
define("_LINKRATING","Balant Reytingi");
define("_HIGHRATING","Yksek Puan");
define("_LOWRATING","Alak Puan");
define("_NUMOFCOMMENTS","Yorum Says");
define("_WEIGHNOTE","* Not: Bu kaynak kaytl ve kaytsz oylar arlkldr");
define("_NOUNREGUSERSVOTES","Kaytsz Kullanc Oyu Yok");
define("_WEIGHOUTNOTE","* Not: Bu kaynak kaytl ve dardan oylar arlkldr");
define("_NOOUTSIDEVOTES","Dardan Oy Yok");
define("_OUTSIDEVOTERS","Dardan Oylayanlar");
define("_UNREGISTEREDUSERS","Kaytsz Kullanclar");
define("_PROMOTEYOURSITE","Sitenizi Tantn");
define("_PROMOTE01","Belki 'Siteye Puan Ver' seeneklerimizden biriyle ilgilenebilirsiniz. Bunlar kaynanza bir grafik (veya bir form) koyarak aldnz oy saysn artrmay amalyor. Ltfen aadaki seeneklerden birini sein:");
define("_TEXTLINK","Metin Balant");
define("_PROMOTE02","Puanlama formuna ulamann basit bir yolu metin balantdr:");
define("_HTMLCODE1","Bu durumda kullanmanz gereken HTML kodu aadadr:");
define("_THENUMBER","Say");
define("_IDREFER","HTML kayna referanslarnda $sitename veritabanndaki site ID'niz bulunur. Bu numarann doruluundan emin olun.");
define("_BUTTONLINK","Buton Balant");
define("_PROMOTE03","Basit bir metin balantdan daha fazlasn aryorsanz, kk bir buton balant kullanmak isteyebilirsiniz:");
define("_RATEIT","Bu Siteye Puan Verin!");
define("_HTMLCODE2","Yukardaki buton iin kaynak kodu:");
define("_REMOTEFORM","Uzaktan Puanlama Formu");
define("_PROMOTE04","Bunda hile yapmaya alrsanz balantnz silinir. Uzaktan puanlama formu buna benzer.");
define("_VOTE4THISSITE","Bu Siteye Oy Verin!");
define("_LINKVOTE","Oy Ver!");
define("_HTMLCODE3","Bu formu kullanarak kullanclar kaynanz kendi sitenizden oylayabilirler. Yukardaki form pasiftir, fakat aadaki kodu sitenize kopyalarsanz alacaktr:");
define("_PROMOTE05","Teekkrler! ve puanlamalarda baarlar!");
define("_STAFF","Takm");
define("_THANKSBROKEN","Bu dizin almalarna katkda bulunduunuz iin teekkrler.");
define("_THANKSFORINFO","Bilgi iin teekkrler.");
define("_LOOKTOREQUEST","steiniz ksa sre iinde deerlendirilecek.");
define("_REQUESTLINKMOD","Balant Deiiklii ste");
define("_LINKID","Balant ID");
define("_SENDREQUEST","stek Gnder");
define("_THANKSTOTAKETIME","Burada bir site puanladnz iin teekkrler:");
define("_LETSDECIDE","Sizin gibi kullanclarn oylar dier kullanclarn daha iyi balantlar semesi yardmc olacaktr.");
define("_RETURNTO","Geri Dn:");
define("_RATENOTE1","Ltfen bir kayna bir kereden fazla oylamayn.");
define("_RATENOTE2","l 1 - 10 arasdr, 1 zayf ve 10 mkemmel.");
define("_RATENOTE3","Ltfen objektif olun, herkes 1 veya 10 alrsa, puanlar kullanl olamaz.");
define("_RATENOTE4","<a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">En yi Kaynaklar</a> listesini grebilirsiniz.");
define("_RATENOTE5","Kendi kaynanz oylamayn.");
define("_YOUAREREGGED","Kaytl kullancsnz ve giri yapmsnz.");
define("_FEELFREE2ADD","Bu site hakknda yorum ekleyebilirsiniz.");
define("_YOUARENOTREGGED","Kaytl deilsiniz veya giri yapmamsnz.");
define("_IFYOUWEREREG","Kaytl olsaydnz site hakknda yorum yazabilecektiniz.");
define("_WEBLINKS","Web Balantlar");
define("_TITLE","Balk");
define("_MODIFY","Deitir");
define("_COMPLETEVOTE1","Oyunuz deerlendirilmitir.");
define("_COMPLETEVOTE2","Son $anonwaitdays gn iinde zaten oyunuzu kullanmsnz.");
define("_COMPLETEVOTE3","Sadece bir kez oy kullann.<br>Tm oylar keydedilir ve incelenir.");
define("_COMPLETEVOTE4","Kendi nerdiiniz link iin oy kullanamazsnz.<br>Tm oylar keydedilir ve incelenir.");
define("_COMPLETEVOTE5","Puan seilmemi - oy verilmedi");
define("_COMPLETEVOTE6","Her IP adresi $outsidewaitdays gn iinde sadece bir oy kullanabilir.");
define("_LINKSDATESTRING","%e-%m-%y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Web_Links/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_YOURNAME","sminiz");
define("_CATEGORY","Kategori");
define("_CATEGORIES","Kategori");
define("_LVOTES","oy");
define("_TOTALVOTES","Toplam Oy:");
define("_LINKTITLE","Balant Bal");
define("_HITS","Hit");
define("_THEREARE","Veritabannda");
define("_NOMATCHES","Uygun sonu bulunamad");
define("_SCOMMENTS","Yorum");
define("_DESCRIPTION","Tanm");
define("_ONLYREGUSERSMODIFY","Sadece kaytl kullanclar dosya deiiklik bavurusu yapabilir. Ltfen <a href=\"modules.php?name=Your_Account\">kayt olun veya giri yapn</a>.");
define("_DATE","Tarih");
define("_TO","Kime");
define("_ADDLINK","Balant Ekle");
define("_NEW","Yeni");
define("_POPULAR","Popler");
define("_TOPRATED","En yi");
define("_RANDOM","Rastgele");
define("_LINKSMAIN","Balantlar Anasayfa");
define("_LINKCOMMENTS","Balant Yorumlar");
define("_ADDITIONALDET","Ek Detaylar");
define("_EDITORREVIEW","Editr zlenimi");
define("_REPORTBROKEN","Krk Balant Bildir");
define("_LINKSMAINCAT","Balant Ana Kategorileri");
define("_AND","ve");
define("_INDB","bulunuyor");
define("_ADDALINK","Yeni Balant Ekle");
define("_INSTRUCTIONS","Aklamalar");
define("_SUBMITONCE","Bir balanty sadece bir kez gnderin.");
define("_POSTPENDING","Gnderilen tm balantlar onaylanmaldr.");
define("_USERANDIP","Kullanc ve IP adresi kaydedilir. Bu yzden sistemi ktye kullanmayn.");
define("_PAGETITLE","Sayfa Bal");
define("_PAGEURL","Sayfa Adresi");
define("_YOUREMAIL","Email'iniz");
define("_LDESCRIPTION","Tanm: (En fazla 255 karakter)");
define("_ADDURL","Adres Ekle");
define("_LINKSNOTUSER1","Kaytl deilsiniz veya giri yapmamsnz.");
define("_LINKSNOTUSER2","Kaytl olsaydnz bu siteye balant gnderebilecektiniz.");
define("_LINKSNOTUSER3","Kaytl kullanc olmak ksa ve basit bir ilemdir.");
define("_LINKSNOTUSER4","Neden baz zelliklere eriim iin kayt gerekli?");
define("_LINKSNOTUSER5","nk size en kaliteli ierii sunabilmek iin,");
define("_LINKSNOTUSER6","her e tek tek editrlerimiz tarafndan incelenip onaylanyor.");
define("_LINKSNOTUSER7","Size sadece deerli bilgielr sunmak istiyoruz.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Hesap Kayd</a>");
define("_LINKALREADYEXT","HATA: Bu adres zaten veritabanmzda kaytl!");
define("_LINKNOTITLE","HATA: Adres iin BALIK girmelisiniz!");
define("_LINKNOURL","HATA: Adres iin bir URL girmelisiniz!");
define("_LINKNODESC","HATA: Adres iin bir TANIM girmelisiniz!");
define("_LINKRECEIVED","Balant neriniz alnd. Teekkrler!");
define("_EMAILWHENADD","Kabul edildiinde bir email alacaksnz.");
define("_CHECKFORIT","Bir email adresi yazmadnz. Yine de balantnz kontrol edilecek.");
define("_NEWLINKS","Yeni Balantlar");
define("_TOTALNEWLINKS","Yeni Balantlar");
define("_LASTWEEK","Geen Hafta");
define("_LAST30DAYS","Son 30 Gn");
define("_1WEEK","1 Hafta");
define("_2WEEKS","2 Hafta");
define("_30DAYS","30 Gn");
define("_SHOW","Gster");
define("_TOTALFORLAST","Yeni linkler: Son");
define("_DAYS","gn");
define("_ADDEDON","Eklenme");
define("_RATING","Puan");
define("_RATESITE","Siteye Puan Ver");
define("_DETAILS","Detaylar");
define("_BESTRATED","En yi Balantlar - Top");
define("_OF","");
define("_TRATEDLINKS","toplam balant");
define("_TVOTESREQ","minimum oy gerekir");
define("_SHOWTOP","En yi");
define("_MOSTPOPULAR","En Popler - Top");
define("_OFALL","of all");
define("_SORTLINKSBY","Balantlar Srala");
define("_SITESSORTED","u Anki Sralama");
define("_POPULARITY","Poplerlik");
define("_SELECTPAGE","Sayfa Sein");
define("_MAIN","Anasayfa");
define("_NEWTODAY","Bugn");
define("_NEWLAST3DAYS","Son 3 Gn");
define("_NEWTHISWEEK","Bu Hafta");
define("_CATNEWTODAY","Bu Kategoriye Bugn Eklenen Balantlar");
define("_CATLAST3DAYS","Bu Kategoriye Son 3 Gn inde Eklenenler");
define("_CATTHISWEEK","Bu Kategoriye Bu Hafta Eklenen Balantlar");
define("_POPULARITY1","Poplerlik (En Azdan En Yksee)");
define("_POPULARITY2","Poplerlik (En Yksekten En Aza)");
define("_TITLEAZ","Balk (A - Z)");
define("_TITLEZA","Balk (Z - A)");
define("_DATE1","Tarih (Eskiler Baa)");
define("_DATE2","Tarih (Yeniler Baa)");
define("_RATING1","Puan (Dkten Yksee)");
define("_RATING2","Paun (Yksekten De)");
define("_SEARCHRESULTS4","Arama Sonular:");
define("_USUBCATEGORIES","Alt-Kategori");
define("_LINKS","Balant");
define("_TRY2SEARCH","");
define("_INOTHERSENGINES","iin dier arama motorlarn deneyin");
define("_EDITORIAL","Editrel");
define("_LINKPROFILE","Balant Profili");
define("_EDITORIALBY","Editrel:");
define("_NOEDITORIAL","Bu site iin u an editrel yok.");
define("_VISITTHISSITE","Siteyi Ziyaret Et");
define("_RATETHISSITE","Bu Kaynaa Puan Ver");
define("_ISTHISYOURSITE","Bu sizin kaynanz m?");
define("_ALLOWTORATE","Dier kullanclarn sitenizden oy vermesini salayn!");
define("_LINKRATINGDET","Balant Puan Detaylar");
define("_OVERALLRATING","Puan");
define("_TOTALOF","Toplam");
define("_USER","Kullanc");
define("_USERAVGRATING","Ortalama Puan");
define("_NUMRATINGS","Puan Says");
define("_EDITTHISLINK","Balant Dzenle");
define("_REGISTEREDUSERS","Kaytl Kullanc");
define("_NUMBEROFRATINGS","Puan Says");
define("_NOREGUSERSVOTES","Kaytl Kullanc Oyu Yok");
define("_BREAKDOWNBYVAL","Deer Bakmndan Oylar");
define("_LTOTALVOTES","toplam oy");
define("_LINKRATING","Balant Reytingi");
define("_HIGHRATING","Yksek Puan");
define("_LOWRATING","Alak Puan");
define("_NUMOFCOMMENTS","Yorum Says");
define("_WEIGHNOTE","* Not: Bu kaynak kaytl ve kaytsz oylar arlkldr");
define("_NOUNREGUSERSVOTES","Kaytsz Kullanc Oyu Yok");
define("_WEIGHOUTNOTE","* Not: Bu kaynak kaytl ve dardan oylar arlkldr");
define("_NOOUTSIDEVOTES","Dardan Oy Yok");
define("_OUTSIDEVOTERS","Dardan Oylayanlar");
define("_UNREGISTEREDUSERS","Kaytsz Kullanclar");
define("_PROMOTEYOURSITE","Sitenizi Tantn");
define("_PROMOTE01","Belki 'Siteye Puan Ver' seeneklerimizden biriyle ilgilenebilirsiniz. Bunlar kaynanza bir grafik (veya bir form) koyarak aldnz oy saysn artrmay amalyor. Ltfen aadaki seeneklerden birini sein:");
define("_TEXTLINK","Metin Balant");
define("_PROMOTE02","Puanlama formuna ulamann basit bir yolu metin balantdr:");
define("_HTMLCODE1","Bu durumda kullanmanz gereken HTML kodu aadadr:");
define("_THENUMBER","Say");
define("_IDREFER","HTML kayna referanslarnda $sitename veritabanndaki site ID'niz bulunur. Bu numarann doruluundan emin olun.");
define("_BUTTONLINK","Buton Balant");
define("_PROMOTE03","Basit bir metin balantdan daha fazlasn aryorsanz, kk bir buton balant kullanmak isteyebilirsiniz:");
define("_RATEIT","Bu Siteye Puan Verin!");
define("_HTMLCODE2","Yukardaki buton iin kaynak kodu:");
define("_REMOTEFORM","Uzaktan Puanlama Formu");
define("_PROMOTE04","Bunda hile yapmaya alrsanz balantnz silinir. Uzaktan puanlama formu buna benzer.");
define("_VOTE4THISSITE","Bu Siteye Oy Verin!");
define("_LINKVOTE","Oy Ver!");
define("_HTMLCODE3","Bu formu kullanarak kullanclar kaynanz kendi sitenizden oylayabilirler. Yukardaki form pasiftir, fakat aadaki kodu sitenize kopyalarsanz alacaktr:");
define("_PROMOTE05","Teekkrler! ve puanlamalarda baarlar!");
define("_STAFF","Takm");
define("_THANKSBROKEN","Bu dizin almalarna katkda bulunduunuz iin teekkrler.");
define("_THANKSFORINFO","Bilgi iin teekkrler.");
define("_LOOKTOREQUEST","steiniz ksa sre iinde deerlendirilecek.");
define("_REQUESTLINKMOD","Balant Deiiklii ste");
define("_LINKID","Balant ID");
define("_SENDREQUEST","stek Gnder");
define("_THANKSTOTAKETIME","Burada bir site puanladnz iin teekkrler:");
define("_LETSDECIDE","Sizin gibi kullanclarn oylar dier kullanclarn daha iyi balantlar semesi yardmc olacaktr.");
define("_RETURNTO","Geri Dn:");
define("_RATENOTE1","Ltfen bir kayna bir kereden fazla oylamayn.");
define("_RATENOTE2","l 1 - 10 arasdr, 1 zayf ve 10 mkemmel.");
define("_RATENOTE3","Ltfen objektif olun, herkes 1 veya 10 alrsa, puanlar kullanl olamaz.");
define("_RATENOTE4","<a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">En yi Kaynaklar</a> listesini grebilirsiniz.");
define("_RATENOTE5","Kendi kaynanz oylamayn.");
define("_YOUAREREGGED","Kaytl kullancsnz ve giri yapmsnz.");
define("_FEELFREE2ADD","Bu site hakknda yorum ekleyebilirsiniz.");
define("_YOUARENOTREGGED","Kaytl deilsiniz veya giri yapmamsnz.");
define("_IFYOUWEREREG","Kaytl olsaydnz site hakknda yorum yazabilecektiniz.");
define("_WEBLINKS","Web Balantlar");
define("_TITLE","Balk");
define("_MODIFY","Deitir");
define("_COMPLETEVOTE1","Oyunuz deerlendirilmitir.");
define("_COMPLETEVOTE2","Son $anonwaitdays gn iinde zaten oyunuzu kullanmsnz.");
define("_COMPLETEVOTE3","Sadece bir kez oy kullann.<br>Tm oylar keydedilir ve incelenir.");
define("_COMPLETEVOTE4","Kendi nerdiiniz link iin oy kullanamazsnz.<br>Tm oylar keydedilir ve incelenir.");
define("_COMPLETEVOTE5","Puan seilmemi - oy verilmedi");
define("_COMPLETEVOTE6","Her IP adresi $outsidewaitdays gn iinde sadece bir oy kullanabilir.");
define("_LINKSDATESTRING","%e-%m-%y");

?>
